
package amarquee;

/**
 * The listener interface for receiving AMarquee events. 
 *
 * @version 1.0 14/06/98
 * @author Hkan Parting
 */
interface AMarqueeListener {

	/**
	 * Invoked when a QSession has been successfully connected to a remote host.
	 */
	public void aMarqueeConnected(AMarqueeEvent event);
	/**
	 * Invoked when a QSession has lost its connection or when a connection could not be established
	 */
	public void aMarqueeConnectionLost(AMarqueeEvent event);
	/**
	 * Invoked when a Delete oPeration is received.
	 */
	public void aMarqueeDelVal(AMarqueeEvent event);
	/**
	 * Invoked when an error happened. The QSession should be closed if you get an error here!
	 */
	public void aMarqueeError(AMarqueeEvent event);
	/**
	 * Invoked when a QRunInfo is received after you have requested one with QSession.InfoOp().
	 */
	public void aMarqueeInfo(AMarqueeEvent event);
	/**
	 * Invoked when the server pings you.
	 */
	public void aMarqueePing(AMarqueeEvent event);
	/**
	 * Invoked when a QMessage made with MessageOp is received.
	 */
	public void aMarqueeQMessage(AMarqueeEvent event);
	/**
	 * Invoked when a QSession has sent all packets since last QSession.Go(AMarquee.QGOF_NOTIFY).
	 */
	public void aMarqueeSendDone(AMarqueeEvent event);
	/**
	 * Invoked when a SetOp/StreamOp message has been received.
	 */
	public void aMarqueeSetVal(AMarqueeEvent event);
	/**
	 * Invoked when data you are interested in are changed/added. (SubscribeOp)
	 */
	public void aMarqueeSubAdded(AMarqueeEvent event);
	/**
	 * Invoked when data you are interested in are removed from server. (SubscribeOp)
	 */
	public void aMarqueeSubRemoved(AMarqueeEvent event);
	/**
	 * Invoked when a System Message has been received.
	 */
	public void aMarqueeSysMsg(AMarqueeEvent event);
	/**
	 * You get this when you have done something you are not allowed to do, or if you
	 have sent a MessageOp() which nobody received.
	 */
	public void aMarqueeUnPrivileged(AMarqueeEvent event);
}